@@ -137,17 +137,29 @@ def main(*args, **keywords):
 
                 bootstrap.check(cert, key)
                 return 0
+
             if args.bootstrap_user_name:
+                import bootstrap
+                bootstrap.init(cert, key, cert_path, data_path, certbase, args,
+                               port)
+                if not args.cert_user_name:
+                    return 0
+            if args.clear_user_cert:
+                import bootstrap
+                bootstrap.clear_localuser_certificates(certbase)
+                if not args.cert_user_name:
+                    return 0
+            if args.cert_user_name:
+                cert_user_name = args.cert_user_name
                 try:
-                    pwd.getpwnam(args.bootstrap_user_name)
+                    pwd.getpwnam(cert_user_name)
                 except KeyError:
-                    print _("User %s does not exist") % args.bootstrap_user_name
+                    print _("User %s does not exist") % cert_user_name
                     return 1
 
                 import bootstrap
-
-                bootstrap.init(cert, key, cert_path, data_path, certbase, args,
-                               port, args.bootstrap_user_name)
+                bootstrap.force_user_cert(cert, cert_path, data_path,
+                                          certbase, cert_user_name, dv=ob)
                 return 0
             if args.revoke_cert_id:
                 cert_cmd.revoke_signed_cert(args.revoke_cert_id, data_path,
