@@ -68,7 +68,7 @@ class Wsdl(WsdlBase):
             # консольная команда
             'command': 'cl-core-setup',
             # права для запуска метода
-            'rights': ['configure'],
+            'rights': ['setup_package'],
             # объект содержащий модули для действия
             'logic': {'UpdateConfigs': setup_package.UpdateConfigs},
             # описание действия
@@ -145,7 +145,7 @@ class Wsdl(WsdlBase):
             # категория метода
             'category': __('Update '),
             # заголовок метода
-            'title': __("Update settings"),
+            'title': __("Update Settings"),
             # иконка для графической консоли
             'image': 'calculate-core-dispatch,edit-find-replace,computer',
             # метод в графической консоли
@@ -568,7 +568,7 @@ class Wsdl(WsdlBase):
             # консольная команда
             'command': 'cl-core-variables',
             # права для запуска метода
-            'rights': ['configure'],
+            'rights': ['setup_variables'],
             # объект содержащий модули для действия
             'logic': {'Variables': set_vars.Variables},
             # описание действия
@@ -634,7 +634,7 @@ class Wsdl(WsdlBase):
             # консольная команда
             'command': 'cl-core-custom',
             # права для запуска метода
-            'rights': ['configure'],
+            'rights': ['custom_configure'],
             # объект содержащий модули для действия
             'logic': {'UpdateConfigs': setup_package.UpdateConfigs},
             # описание действия
@@ -672,7 +672,7 @@ class Wsdl(WsdlBase):
             # консольная команда
             'command': 'cl-core-restart',
             # права для запуска метода
-            'rights': ['configure'],
+            'rights': ['core_restart'],
             # объект содержащий модули для действия
             'logic': {'UpdateConfigs': setup_package.UpdateConfigs},
             # описание действия
